@@ -1,7 +1,6 @@
 // Copyright 2019-2021 Tauri Programme within The Commons Conservancy
 // SPDX-License-Identifier: Apache-2.0
 
-use simple_logger::SimpleLogger;
 use tao::{
   event::{ElementState, Event, WindowEvent},
   event_loop::{ControlFlow, EventLoop},
@@ -10,7 +9,7 @@ use tao::{
 
 #[allow(clippy::single_match)]
 fn main() {
-  SimpleLogger::new().init().unwrap();
+  env_logger::init();
   let event_loop = EventLoop::new();
 
   let window = WindowBuilder::new()
