@@ -191,8 +191,7 @@ impl<T: 'static> EventLoop<T> {
             }
           }
           WindowRequest::Focus => {
-            // FIXME: replace with present_with_timestamp
-            window.present();
+            window.present_with_time(gdk_sys::GDK_CURRENT_TIME as _);
           }
           WindowRequest::Resizable(resizable) => window.set_resizable(resizable),
           WindowRequest::Minimized(minimized) => {
@@ -309,9 +308,9 @@ impl<T: 'static> EventLoop<T> {
                 | EventMask::FOCUS_CHANGE_MASK,
             );
 
-            // Resizing `decorations: false` aka borderless
+            // Allow resizing unmaximized borderless window
             window.connect_motion_notify_event(|window, event| {
-              if !window.is_decorated() && window.is_resizable() {
+              if !window.is_decorated() && window.is_resizable() && !window.is_maximized() {
                 if let Some(window) = window.window() {
                   let (cx, cy) = event.root();
                   let edge = hit_test(&window, cx, cy);
