@@ -9,6 +9,14 @@
   target_os = "openbsd"
 ))]
 
+#[cfg(all(feature = "tray", feature = "gtk-tray", feature = "ayatana-tray"))]
+compile_error!("`gtk-tray` and `ayatana-tray` Cargo features cannot be enabled at the same time");
+#[cfg(all(
+  feature = "tray",
+  not(any(feature = "gtk-tray", feature = "ayatana-tray"))
+))]
+compile_error!("You must enable one of `gtk-tray` or `ayatana-tray` Cargo features");
+
 mod clipboard;
 mod event_loop;
 mod global_shortcut;
@@ -16,11 +24,19 @@ mod keyboard;
 mod keycode;
 mod menu;
 mod monitor;
-#[cfg(any(feature = "tray", feature = "ayatana"))]
+#[cfg(all(
+  feature = "tray",
+  any(feature = "gtk-tray", feature = "ayatana-tray"),
+  not(all(feature = "gtk-tray", feature = "ayatana-tray"))
+))]
 mod system_tray;
 mod window;
 
-#[cfg(any(feature = "tray", feature = "ayatana"))]
+#[cfg(all(
+  feature = "tray",
+  any(feature = "gtk-tray", feature = "ayatana-tray"),
+  not(all(feature = "gtk-tray", feature = "ayatana-tray"))
+))]
 pub use self::system_tray::{SystemTray, SystemTrayBuilder};
 pub use self::{
   clipboard::Clipboard,
