@@ -464,8 +464,10 @@ impl UnownedWindow {
   }
 
   pub fn set_menu(&self, menu: Option<Menu>) {
-    unsafe {
-      util::set_menu_async(*self.ns_window, menu);
+    // TODO if None we should set an empty menu
+    // On windows we can remove it, in macOS we can't
+    if let Some(menu) = menu {
+      menu::initialize(menu);
     }
   }
 
